@@ -7,7 +7,9 @@ package {{ $name }};
 
 our $VERSION = '{{ $dist->version }}';
 
+use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
+no if "$]" >= 5.033001, feature => 'multidimensional';
 {{
     ($zilla_plugin) = ($name =~ /^Dist::Zilla::Plugin::(.+)$/g);
 
